pub enum ChatCompletionToolChoiceOptionString {
None,
Auto,
Required,
}Expand description
none means the model will not call any tool and instead generates a message. auto means the model can pick between generating a message or calling one or more tools. required means the model must call one or more tools.
JSON schema
{
"description": "`none` means the model will not call any tool and instead generates a message. `auto` means the model can pick between generating a message or calling one or more tools. `required` means the model must call one or more tools.\n",
"type": "string",
"enum": [
"none",
"auto",
"required"
]
}Variants