pub enum CreateChatCompletionRequestReasoningEffort {
Minimal,
Low,
Medium,
High,
}Expand description
Constrains effort on reasoning for reasoning models. Currently supported values are minimal, low, medium, and high. Reducing reasoning effort can result in faster responses and fewer tokens used on reasoning in a response.
JSON schema
{
"description": "Constrains effort on reasoning for reasoning models. Currently supported values are `minimal`, `low`, `medium`, and `high`. Reducing reasoning effort can result in faster responses and fewer tokens used on reasoning in a response.\n",
"type": "string",
"enum": [
"minimal",
"low",
"medium",
"high"
]
}Variants