pub enum CreateChatCompletionRequestResponseFormat {
Text(ResponseFormatText),
JsonSchema(ResponseFormatJsonSchema),
JsonObject(ResponseFormatJsonObject),
}Expand description
An object specifying the format that the model must output. Setting to { "type": "json_schema", "json_schema": {...} } enables Structured Outputs which guarantees the model will match your supplied JSON schema. Setting to { "type": "json_object" } enables the older JSON mode, which ensures the message the model generates is valid JSON.
JSON schema
{
"description": "An object specifying the format that the model must output. Setting to `{ \"type\": \"json_schema\", \"json_schema\": {...} }` enables Structured Outputs which guarantees the model will match your supplied JSON schema. Setting to `{ \"type\": \"json_object\" }` enables the older JSON mode, which ensures the message the model generates is valid JSON.\n",
"oneOf": [
{
"$ref": "#/definitions/ResponseFormatText"
},
{
"$ref": "#/definitions/ResponseFormatJsonSchema"
},
{
"$ref": "#/definitions/ResponseFormatJsonObject"
}
]
}Variants