pub enum CreateImageRequestResponseFormat {
Url,
B64Json,
}Expand description
The format in which the generated images are returned. Must be
one of url or b64_json.
JSON schema
{
"description": "The format in which the generated images are returned. Must be\none of `url` or `b64_json`.\n",
"default": "url",
"type": "string",
"enum": [
"url",
"b64_json"
]
}Variants