pub enum CreateMessagesRequestSystem {
String(String),
Array(Vec<MessagesTextBlock>),
}Expand description
The system prompt. Can be a string or an array of system content blocks (for prompt caching).
JSON schema
{
"description": "The system prompt. Can be a string or an array of system content\nblocks (for prompt caching).\n",
"oneOf": [
{
"description": "System prompt as a string.",
"type": "string"
},
{
"type": "array",
"items": {
"$ref": "#/definitions/MessagesTextBlock"
}
}
]
}Variants
String(String)
Array(Vec<MessagesTextBlock>)