pub enum ResponseInput {
String(String),
Array(Vec<ResponseInputItem>),
}Expand description
Text, image, or file inputs to the model. Either a single text prompt or a list of input items representing a (possibly batched) conversation.
JSON schema
{
"description": "Text, image, or file inputs to the model. Either a single text prompt or a list of input items representing a (possibly batched) conversation.\n",
"oneOf": [
{
"description": "A text input to the model, equivalent to a user message.",
"type": "string"
},
{
"description": "A list of input items.",
"type": "array",
"items": {
"$ref": "#/definitions/ResponseInputItem"
}
}
]
}Variants
String(String)
Array(Vec<ResponseInputItem>)