pub enum ResponseInputImageDetail {
Auto,
Low,
High,
}Expand description
The detail level of the image to send to the model.
JSON schema
{
"description": "The detail level of the image to send to the model.",
"default": "auto",
"type": "string",
"enum": [
"auto",
"low",
"high"
]
}Variants