pub struct ChatCompletionStreamChoiceLogprobs {
pub content: Vec<ChatCompletionTokenLogprob>,
pub refusal: Vec<ChatCompletionTokenLogprob>,
}Expand description
Log probability information for the choice.
JSON schema
{
"description": "Log probability information for the choice.",
"type": "object",
"required": [
"content",
"refusal"
],
"properties": {
"content": {
"description": "A list of message content tokens with log probability information.",
"type": "array",
"items": {
"$ref": "#/definitions/ChatCompletionTokenLogprob"
}
},
"refusal": {
"description": "A list of message refusal tokens with log probability information.",
"type": "array",
"items": {
"$ref": "#/definitions/ChatCompletionTokenLogprob"
}
}
}
}Fields
content: Vec<ChatCompletionTokenLogprob>A list of message content tokens with log probability information.
refusal: Vec<ChatCompletionTokenLogprob>A list of message refusal tokens with log probability information.