ChatCompletionStreamResponseDelta

Struct ChatCompletionStreamResponseDelta 

pub struct ChatCompletionStreamResponseDelta {
    pub content: Option<String>,
    pub reasoning: Option<String>,
    pub reasoning_content: Option<String>,
    pub refusal: Option<String>,
    pub role: Option<MessageRole>,
    pub tool_calls: Vec<ChatCompletionMessageToolCallChunk>,
}
A chat completion delta generated by streamed model responses.

JSON schema
{
 "description": "A chat completion delta generated by streamed model responses.",
 "type": "object",
 "properties": {
   "content": {
     "description": "The contents of the chunk message.",
     "type": "string"
   },
   "reasoning": {
     "description": "The reasoning of the chunk message. Same as reasoning_content.",
     "type": "string"
   },
   "reasoning_content": {
     "description": "The reasoning content of the chunk message.",
     "type": "string"
   },
   "refusal": {
     "description": "The refusal message generated by the model.",
     "type": "string"
   },
   "role": {
     "$ref": "#/definitions/MessageRole"
   },
   "tool_calls": {
     "type": "array",
     "items": {
       "$ref": "#/definitions/ChatCompletionMessageToolCallChunk"
     }
   }
 }
}

Fields

content: Option<String>

The contents of the chunk message.

reasoning: Option<String>

The reasoning of the chunk message. Same as reasoning_content.

reasoning_content: Option<String>

The reasoning content of the chunk message.

refusal: Option<String>

The refusal message generated by the model.

role: Option<MessageRole>tool_calls: Vec<ChatCompletionMessageToolCallChunk>