pub struct ContextWindow {
pub source: ContextWindowSource,
pub tokens: i64,
}Expand description
Context window information for a model
JSON schema
{
"description": "Context window information for a model",
"type": "object",
"required": [
"source",
"tokens"
],
"properties": {
"source": {
"description": "Source of the context window information",
"type": "string",
"enum": [
"runtime",
"provider",
"community"
]
},
"tokens": {
"description": "Maximum number of tokens the model can process in a single request",
"type": "integer"
}
}
}Fields
source: ContextWindowSourceSource of the context window information
tokens: i64Maximum number of tokens the model can process in a single request