pub struct CreateMessagesRequestThinking {
pub budget_tokens: i64,
pub type_: CreateMessagesRequestThinkingType,
}Expand description
Configuration for extended thinking.
JSON schema
{
"description": "Configuration for extended thinking.\n",
"type": "object",
"required": [
"budget_tokens",
"type"
],
"properties": {
"budget_tokens": {
"description": "The maximum number of tokens the model is allowed to use\nfor thinking.\n",
"type": "integer"
},
"type": {
"description": "Always `enabled`.",
"type": "string",
"enum": [
"enabled"
]
}
}
}Fields
budget_tokens: i64The maximum number of tokens the model is allowed to use for thinking.
type_: CreateMessagesRequestThinkingTypeAlways enabled.