CreateResponseRequest

Struct CreateResponseRequest 

pub struct CreateResponseRequest {
Show 17 fields pub background: bool, pub input: ResponseInput, pub instructions: Option<String>, pub max_output_tokens: Option<i64>, pub metadata: HashMap<String, String>, pub model: String, pub parallel_tool_calls: bool, pub previous_response_id: Option<String>, pub reasoning: Option<ResponseReasoning>, pub store: bool, pub stream: bool, pub temperature: f32, pub text: Option<ResponseTextConfig>, pub tool_choice: Option<ResponseToolChoice>, pub tools: Vec<ResponseTool>, pub top_p: f32, pub user: Option<String>,
}
Request body for creating a model response via the Responses API.

JSON schema
{
 "description": "Request body for creating a model response via the Responses API.\n",
 "type": "object",
 "required": [
   "input",
   "model"
 ],
 "properties": {
   "background": {
     "description": "Whether to run the model response in the background. Useful for long-running or batched requests.\n",
     "default": false,
     "type": "boolean"
   },
   "input": {
     "$ref": "#/definitions/ResponseInput"
   },
   "instructions": {
     "description": "A system (or developer) message inserted into the model's context. When used with `previous_response_id`, instructions from previous responses are not carried over.\n",
     "type": "string",
     "nullable": true
   },
   "max_output_tokens": {
     "description": "An upper bound for the number of tokens that can be generated for a response, including visible output tokens and reasoning tokens.\n",
     "type": "integer",
     "nullable": true
   },
   "metadata": {
     "description": "Set of up to 16 key-value pairs that can be attached to the object and returned when retrieving the response.\n",
     "type": "object",
     "additionalProperties": {
       "type": "string"
     }
   },
   "model": {
     "description": "Model ID used to generate the response.",
     "type": "string"
   },
   "parallel_tool_calls": {
     "description": "Whether to allow the model to run tool calls in parallel.",
     "default": true,
     "type": "boolean"
   },
   "previous_response_id": {
     "description": "The unique ID of the previous response to the model. Use this to create multi-turn conversations.\n",
     "type": "string",
     "nullable": true
   },
   "reasoning": {
     "$ref": "#/definitions/ResponseReasoning"
   },
   "store": {
     "description": "Whether to store the generated model response for later retrieval.\n",
     "default": true,
     "type": "boolean"
   },
   "stream": {
     "description": "If set to true, the model response data is streamed to the client as it is generated using [server-sent events](https://developer.mozilla.org/en-US/docs/Web/API/Server-sent_events/Using_server-sent_events#Event_stream_format).\n",
     "default": false,
     "type": "boolean"
   },
   "temperature": {
     "description": "What sampling temperature to use, between 0 and 2. Higher values make the output more random; lower values make it more focused.\n",
     "default": 1,
     "type": "number",
     "format": "float",
     "nullable": true
   },
   "text": {
     "$ref": "#/definitions/ResponseTextConfig"
   },
   "tool_choice": {
     "$ref": "#/definitions/ResponseToolChoice"
   },
   "tools": {
     "description": "An array of tools the model may call while generating a response.\n",
     "type": "array",
     "items": {
       "$ref": "#/definitions/ResponseTool"
     }
   },
   "top_p": {
     "description": "An alternative to sampling with temperature, called nucleus sampling, where the model considers the tokens with `top_p` probability mass.\n",
     "default": 1,
     "type": "number",
     "format": "float",
     "nullable": true
   },
   "user": {
     "description": "A stable identifier for your end-users, used to help detect and prevent abuse.\n",
     "type": "string"
   }
 }
}

Fields

background: bool

Whether to run the model response in the background. Useful for long-running or batched requests.

input: ResponseInputinstructions: Option<String>

A system (or developer) message inserted into the model’s context. When used with previous_response_id, instructions from previous responses are not carried over.

max_output_tokens: Option<i64>

An upper bound for the number of tokens that can be generated for a response, including visible output tokens and reasoning tokens.

metadata: HashMap<String, String>

Set of up to 16 key-value pairs that can be attached to the object and returned when retrieving the response.

model: String

Model ID used to generate the response.

parallel_tool_calls: bool

Whether to allow the model to run tool calls in parallel.

previous_response_id: Option<String>

The unique ID of the previous response to the model. Use this to create multi-turn conversations.

reasoning: Option<ResponseReasoning>store: bool

Whether to store the generated model response for later retrieval.

stream: bool

If set to true, the model response data is streamed to the client as it is generated using server-sent events.

temperature: f32

What sampling temperature to use, between 0 and 2. Higher values make the output more random; lower values make it more focused.

text: Option<ResponseTextConfig>tool_choice: Option<ResponseToolChoice>tools: Vec<ResponseTool>

An array of tools the model may call while generating a response.

top_p: f32

An alternative to sampling with temperature, called nucleus sampling, where the model considers the tokens with top_p probability mass.

user: Option<String>

A stable identifier for your end-users, used to help detect and prevent abuse.