pub struct FunctionObject {
pub description: Option<String>,
pub name: String,
pub parameters: Option<FunctionParameters>,
pub strict: bool,
}Expand description
FunctionObject
JSON schema
{
"type": "object",
"required": [
"name"
],
"properties": {
"description": {
"description": "A description of what the function does, used by the model to choose when and how to call the function.",
"type": "string"
},
"name": {
"description": "The name of the function to be called. Must be a-z, A-Z, 0-9, or contain underscores and dashes, with a maximum length of 64.",
"type": "string"
},
"parameters": {
"$ref": "#/definitions/FunctionParameters"
},
"strict": {
"description": "Whether to enable strict schema adherence when generating the function call. If set to true, the model will follow the exact schema defined in the `parameters` field. Only a subset of JSON Schema is supported when `strict` is `true`. Learn more about Structured Outputs in the [function calling guide](docs/guides/function-calling).",
"default": false,
"type": "boolean"
}
}
}Fields
description: Option<String>A description of what the function does, used by the model to choose when and how to call the function.
name: StringThe name of the function to be called. Must be a-z, A-Z, 0-9, or contain underscores and dashes, with a maximum length of 64.
parameters: Option<FunctionParameters>strict: boolWhether to enable strict schema adherence when generating the function call. If set to true, the model will follow the exact schema defined in the parameters field. Only a subset of JSON Schema is supported when strict is true. Learn more about Structured Outputs in the function calling guide.