pub struct Image {
pub b64_json: Option<String>,
pub revised_prompt: Option<String>,
pub url: Option<String>,
}Expand description
Represents the url or the content of an image generated by the Images API.
JSON schema
{
"description": "Represents the url or the content of an image generated by the Images API.",
"type": "object",
"properties": {
"b64_json": {
"description": "The base64-encoded JSON of the generated image, if\n`response_format` is `b64_json`.\n",
"type": "string"
},
"revised_prompt": {
"description": "The prompt that was used to generate the image, if there was any\nrevision to the prompt.\n",
"type": "string"
},
"url": {
"description": "The URL of the generated image, if `response_format` is `url`\n(default).\n",
"type": "string"
}
}
}Fields
b64_json: Option<String>The base64-encoded JSON of the generated image, if
response_format is b64_json.
revised_prompt: Option<String>The prompt that was used to generate the image, if there was any revision to the prompt.
url: Option<String>The URL of the generated image, if response_format is url
(default).