pub struct MessagesOutputConfig {
pub effort: Option<MessagesOutputConfigEffort>,
}Expand description
Output configuration for a Messages API request.
JSON schema
{
"description": "Output configuration for a Messages API request.\n",
"type": "object",
"properties": {
"effort": {
"description": "Constrains how much effort the model spends on reasoning.\nLower effort yields faster responses and fewer reasoning\ntokens.\n",
"type": "string",
"enum": [
"low",
"medium",
"high",
"xhigh",
"max"
]
}
}
}Fields
effort: Option<MessagesOutputConfigEffort>Constrains how much effort the model spends on reasoning. Lower effort yields faster responses and fewer reasoning tokens.