pub struct MessagesRedactedThinkingBlock {
pub data: String,
pub type_: MessagesRedactedThinkingBlockType,
}Expand description
A redacted thinking content block in a Messages API request or response. Emitted when thinking content is encrypted for safety reasons; must be passed back unchanged in multi-turn conversations.
JSON schema
{
"description": "A redacted thinking content block in a Messages API request or\nresponse. Emitted when thinking content is encrypted for safety\nreasons; must be passed back unchanged in multi-turn conversations.\n",
"type": "object",
"required": [
"data",
"type"
],
"properties": {
"data": {
"description": "The encrypted thinking content.",
"type": "string"
},
"type": {
"description": "Content type identifier. Always `redacted_thinking`.",
"type": "string",
"enum": [
"redacted_thinking"
]
}
}
}Fields
data: StringThe encrypted thinking content.
type_: MessagesRedactedThinkingBlockTypeContent type identifier. Always redacted_thinking.