pub struct ResponseFormatJsonObject {
pub type_: ResponseFormatJsonObjectType,
}Expand description
JSON object response format. An older method of generating JSON responses. Using json_schema is recommended for models that support it. Note that the model will not generate JSON without a system or user message instructing it to do so.
JSON schema
{
"description": "JSON object response format. An older method of generating JSON responses. Using `json_schema` is recommended for models that support it. Note that the model will not generate JSON without a system or user message instructing it to do so.\n",
"type": "object",
"required": [
"type"
],
"properties": {
"type": {
"description": "The type of response format being defined. Always `json_object`.",
"type": "string",
"enum": [
"json_object"
]
}
}
}Fields
type_: ResponseFormatJsonObjectTypeThe type of response format being defined. Always json_object.