pub struct ResponseFormatJsonSchema {
pub json_schema: ResponseFormatJsonSchemaJsonSchema,
pub type_: ResponseFormatJsonSchemaType,
}Expand description
JSON Schema response format. Used to generate structured JSON responses.
JSON schema
{
"description": "JSON Schema response format. Used to generate structured JSON responses.\n",
"type": "object",
"required": [
"json_schema",
"type"
],
"properties": {
"json_schema": {
"description": "Structured Outputs configuration options, including a JSON Schema.",
"type": "object",
"required": [
"name"
],
"properties": {
"description": {
"description": "A description of what the response format is for, used by the model to determine how to respond in the format.\n",
"type": "string"
},
"name": {
"description": "The name of the response format. Must be a-z, A-Z, 0-9, or contain underscores and dashes, with a maximum length of 64.\n",
"type": "string"
},
"schema": {
"$ref": "#/definitions/ResponseFormatJsonSchemaSchema"
},
"strict": {
"description": "Whether to enable strict schema adherence when generating the output. If set to true, the model will always follow the exact schema defined in the `schema` field. Only a subset of JSON Schema is supported when `strict` is `true`.\n",
"default": false,
"type": "boolean"
}
}
},
"type": {
"description": "The type of response format being defined. Always `json_schema`.",
"type": "string",
"enum": [
"json_schema"
]
}
}
}Fields
json_schema: ResponseFormatJsonSchemaJsonSchematype_: ResponseFormatJsonSchemaTypeThe type of response format being defined. Always json_schema.