pub struct ResponseFunctionToolCall {
pub arguments: String,
pub call_id: String,
pub id: Option<String>,
pub name: String,
pub status: Option<ResponseFunctionToolCallStatus>,
pub type_: ResponseFunctionToolCallType,
}Expand description
A tool call to a function generated by the model.
JSON schema
{
"description": "A tool call to a function generated by the model.",
"type": "object",
"required": [
"arguments",
"call_id",
"name",
"type"
],
"properties": {
"arguments": {
"description": "A JSON string of the arguments to pass to the function.",
"type": "string"
},
"call_id": {
"description": "The unique ID of the function tool call generated by the model, used to associate the call with its output.\n",
"type": "string"
},
"id": {
"description": "The unique ID of the function tool call.",
"type": "string"
},
"name": {
"description": "The name of the function to run.",
"type": "string"
},
"status": {
"description": "The status of the function tool call.",
"type": "string",
"enum": [
"in_progress",
"completed",
"incomplete"
]
},
"type": {
"description": "The type of the output item. Always `function_call`.",
"type": "string",
"enum": [
"function_call"
]
}
}
}Fields
arguments: StringA JSON string of the arguments to pass to the function.
call_id: StringThe unique ID of the function tool call generated by the model, used to associate the call with its output.
id: Option<String>The unique ID of the function tool call.
name: StringThe name of the function to run.
status: Option<ResponseFunctionToolCallStatus>The status of the function tool call.
type_: ResponseFunctionToolCallTypeThe type of the output item. Always function_call.