pub struct ResponseInputImage {
pub detail: ResponseInputImageDetail,
pub image_url: Option<String>,
pub type_: ResponseInputImageType,
}Expand description
An image input to the model.
JSON schema
{
"description": "An image input to the model.",
"type": "object",
"required": [
"type"
],
"properties": {
"detail": {
"description": "The detail level of the image to send to the model.",
"default": "auto",
"type": "string",
"enum": [
"auto",
"low",
"high"
]
},
"image_url": {
"description": "The URL of the image (data URLs supported).",
"type": "string"
},
"type": {
"description": "The type of the input item. Always `input_image`.",
"type": "string",
"enum": [
"input_image"
]
}
}
}Fields
detail: ResponseInputImageDetailThe detail level of the image to send to the model.
image_url: Option<String>The URL of the image (data URLs supported).
type_: ResponseInputImageTypeThe type of the input item. Always input_image.