pub struct ResponseTextConfigFormat {
pub name: Option<String>,
pub schema: Option<FunctionParameters>,
pub strict: bool,
pub type_: ResponseTextConfigFormatType,
}Expand description
An object specifying the format that the model must output.
JSON schema
{
"description": "An object specifying the format that the model must output.",
"type": "object",
"required": [
"type"
],
"properties": {
"name": {
"description": "The name of the response format (used with `json_schema`).",
"type": "string"
},
"schema": {
"$ref": "#/definitions/FunctionParameters"
},
"strict": {
"description": "Whether to enable strict schema adherence.",
"default": false,
"type": "boolean"
},
"type": {
"description": "The type of response format being defined.",
"type": "string",
"enum": [
"text",
"json_schema",
"json_object"
]
}
}
}Fields
name: Option<String>The name of the response format (used with json_schema).
schema: Option<FunctionParameters>strict: boolWhether to enable strict schema adherence.
type_: ResponseTextConfigFormatTypeThe type of response format being defined.